summaryrefslogtreecommitdiffstats
path: root/ksysv/kscroller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/kscroller.h')
-rw-r--r--ksysv/kscroller.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksysv/kscroller.h b/ksysv/kscroller.h
index 5b63346..77a78f9 100644
--- a/ksysv/kscroller.h
+++ b/ksysv/kscroller.h
@@ -70,7 +70,7 @@ public slots:
void setCornerWidget (TQWidget* corner);
/**
* Update the scrollbars. Call whenever you change the contents minimumSize.
*/
void updateScrollBars ();
@@ -83,12 +83,12 @@ protected:
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
private slots:
@@ -70,7 +70,7 @@ public slots:
void setCornerWidget (TQWidget* corner);
/**
- * Update the scrollbars. Call whenever you change the contents minimumSize.
+ * Update the scrollbars. Call whenever you change the contents tqminimumSize.
*/
void updateScrollBars ();